package com.muyu.ruleEngine.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.ruleEngine.domain.EngineConfig;
import com.muyu.ruleEngine.domain.model.TestData;
import com.muyu.ruleEngine.domain.req.EngineConfigEditReq;
import com.muyu.ruleEngine.domain.req.EngineConfigQueryReq;
import com.muyu.ruleEngine.domain.req.EngineConfigSaveReq;
import com.muyu.ruleEngine.domain.resp.EngineConfigScopeResp;
import com.muyu.ruleEngine.service.EngineConfigService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import java.util.List;

/**
 * 引擎配置Controller
 *
 * @author DeKangLiu
 * @date 2024-05-02
 */
@Api(tags = "引擎配置")
@RestController
@RequestMapping("/config")
public class EngineConfigController extends BaseController {

    @Autowired
    private EngineConfigService engineConfigService;

    /**
     * 获取引擎配置作用域列表
     */
    @ApiOperation("获取引擎配置作用域列表")
    @RequiresPermissions("rule_engine:config:list")
    @GetMapping("/getScopeList")
    public Result<List<EngineConfigScopeResp>> getScopeList() {
        return Result.success(engineConfigService.getScopeList());
    }

    /**
     * 通过引擎作用域编号获取引擎配置作用域信息
     */
    @ApiOperation("通过引擎作用域编号获取引擎配置作用域信息")
    @RequiresPermissions("rule_engine:config:list")
    @GetMapping("/getScopeInfo/{id}")
    public Result<EngineConfigScopeResp> getScopeInfoById(@PathVariable Integer id) {
        return Result.success(engineConfigService.getScopeInfoById(id));
    }

    /**
     * 查询引擎规则配置列表
     */
    @ApiOperation("获取引擎规则配置列表")
    @RequiresPermissions("ruleEngine:config:list")
    @GetMapping("/list")
    public Result<List<EngineConfig>> list(EngineConfigQueryReq engineConfigQueryReq) {
        return Result.success(engineConfigService.list(EngineConfig.queryBuild(engineConfigQueryReq)));
    }

    /**
     * 测试引擎规则配置
     */
    @ApiOperation("测试引擎规则配置")
    @RequiresPermissions("ruleEngine:config:add")
    @PostMapping(value = "/test")
    public Result<Object> ruleTest(@RequestBody TestData testData) {
        return Result.success(engineConfigService.ruleTest(testData));
    }

    /**
     * 新增引擎规则配置
     */
    @RequiresPermissions("ruleEngine:config:add")
    @Log(title = "引擎规则配置", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增引擎规则配置")
    public Result<String> add(@RequestBody EngineConfigSaveReq engineConfigSaveReq) {
        return toAjax(engineConfigService.save(EngineConfig.saveBuild(engineConfigSaveReq, SecurityUtils::getUsername)));
    }

    /**
     * 修改引擎规则配置
     */
    @RequiresPermissions("ruleEngine:config:edit")
    @Log(title = "引擎规则配置", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改引擎规则配置")
    public Result<String> edit(@PathVariable Long id, @RequestBody EngineConfigEditReq engineConfigEditReq) {
        return toAjax(engineConfigService.updateById(EngineConfig.editBuild(id,engineConfigEditReq, SecurityUtils::getUsername)));
    }

    /**
     * 删除引擎规则配置
     */
    @RequiresPermissions("ruleEngine:config:remove")
    @Log(title = "引擎规则配置", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation("删除引擎规则配置")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(engineConfigService.removeBatchByIds(ids));
    }

}
